==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Akey sit la',
'articles' => 'Atik yo',
'articles_auteur' => 'Tout atik lot&egrave; a',
'articles_populaires' => 'Atik yo ki plis popil&egrave;',
'articles_rubrique' => 'Atik yo nan ribrik sa-a',
'aucun_article' => 'Gen pa oken atik sou ladr&egrave;s la',
'aucun_auteur' => 'Gen pa oken lot&egrave; sou ladr&egrave;s la',
'aucun_site' => 'Gen pa oken sit sou ladr&egrave;s la',
'aucune_breve' => 'Gen pa oken tinouv&egrave;l sou ladr&egrave;s la',
'aucune_rubrique' => 'Gen pa oken ribrik sou ladr&egrave;s la',
'autres' => '<NEW>Ot',
'autres_breves' => 'L&ograve;t tinouv&egrave;l yo',
'autres_groupes_mots_clefs' => 'L&ograve;t gwoup mokle yo',
'autres_sites' => 'L&ograve;t sit yo',

// B
'bonjour' => 'Bonjou',
'breves' => 'Tinouv&egrave;l yo',

// C
'commenter_site' => 'L&egrave;s yon komant&egrave; sou sit la',
'copie_document_impossible' => '<NEW>Pa ka kopye dokiman la',

// D
'date' => 'Dat',
'dernier_ajout' => 'D&egrave;nye bagay ki ajoute',
'dernieres_breves' => 'D&egrave;nye tinouv&egrave;l yo',
'derniers_articles' => 'D&egrave;nye atik yo',
'derniers_commentaires' => 'D&egrave;nye komant&egrave; yo',
'derniers_messages_forum' => 'D&egrave;nye mesaj yo ki te piblye nan fowom yo',
'documents_interdits_forum' => '<NEW>Documents interdits dans le forum',

// E
'edition_mode_texte' => 'Ledisyon modt&egrave;ks pou',
'en_reponse' => 'Pou r&eacute;ponn a&nbsp;:',
'en_resume' => 'Nan k&egrave;k mo',
'envoyer_message' => 'Voye yon mesaj',
'espace_prive' => 'Espas priv&eacute;',

// F
'formats_acceptes' => '<NEW>Formats accept&#233;s : @formats@.',
'forum' => 'Fowom',

// H
'hierarchie_site' => 'Estrikti sit sa-a',

// J
'jours' => 'jou yo',

// L
'lien_connecter' => '<NEW>Se connecter',

// M
'meme_auteur' => 'M&egrave;m lot&egrave; ki ekri ank&ograve;',
'meme_rubrique' => 'Andan m&egrave;m ribrik',
'memes_auteurs' => 'M&egrave;m lot&egrave; yo ki ekri ank&ograve;',
'message' => 'Mesaj',
'messages_forum' => 'Mesaj yo nan fowom ',
'messages_recents' => 'Mesaj yo nan fowom ki plis resan',
'mots_clefs' => 'Mokle yo',
'mots_clefs_meme_groupe' => 'Mokle yo nan m&egrave;m gwoup',

// N
'navigation' => 'Toune-vire',
'nom' => 'Kouman rele',
'nouveautes' => 'Nouv&egrave;lt&eacute; yo',
'nouveautes_web' => 'Kisa nouvo sou w&egrave;b la',
'nouveaux_articles' => 'Nouvo atik yo',
'nouvelles_breves' => 'Nouvo tinouv&egrave;l yo',

// P
'page_precedente' => 'paj d&egrave;y&egrave;',
'page_suivante' => 'paj swivan',
'par_auteur' => 'pa',
'participer_site' => 'Ou se kapab soutni vi sit la ek pwopoze ou pwop atik aw. Pou soutni kon sa enskri a w isit anba. Ou ke gen touswit ou kod laks&egrave; nan espas priv&eacute; sit la.',
'plan_site' => 'Kat sit la',
'popularite' => 'Kouman se popil&egrave;',
'poster_message' => 'Voye yon mesaj',
'proposer_site' => 'Ou se kapab pwopoze yon sit pou ajoute nan ribrik la&nbsp;:',

// R
'repondre_article' => 'Reponn sou atik la',
'repondre_breve' => 'Reponn sou tinouv&egrave;l la',
'repondre_message' => 'Reponn sou mesaj la',
'resultats_recherche' => 'Rezilta pou ou ch&egrave;che',
'retour_debut_forums' => 'Tounyen nan koumansman fowom sa-yo',
'rubrique' => 'Ribrik',
'rubriques' => 'Ribrik yo',

// S
'signatures_petition' => 'Siyati yo',
'site_realise_avec_spip' => 'Sit la  se sit ki te f&egrave; ak SPIP',
'sites_web' => 'Sitw&egrave;b yo',
'sous_rubriques' => 'Souribrik yo',
'spam' => '<NEW>Spam',
'suite' => 'swit',
'sur_web' => 'Sou w&egrave;b',
'syndiquer_rubrique' => 'Sindike ribrik la',
'syndiquer_site' => 'Sindike tout sit la m&egrave;m',

// T
'texte_lettre_information' => 'Tala l&egrave;t-enf&ograve;masyon sit la ',
'texte_lettre_information_2' => 'L&egrave;t la ka ramase tout atik ek tinouv&egrave;l yo  te pibliye depi',

// V
'ver_imprimer' => 'V&egrave;syon pou enprime',
'voir_en_ligne' => 'Gad an liy',
'voir_squelette' => 'kou je sou l&eacute;skel&egrave;t paj-la'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Akey sit la',
'article' => 'Article', # NEW
'articles' => 'Atik yo',
'articles_auteur' => 'Tout atik lot&egrave; a',
'articles_populaires' => 'Atik yo ki plis popil&egrave;',
'articles_rubrique' => 'Atik yo nan ribrik sa-a',
'aucun_article' => 'Gen pa oken atik sou ladr&egrave;s la',
'aucun_auteur' => 'Gen pa oken lot&egrave; sou ladr&egrave;s la',
'aucun_site' => 'Gen pa oken sit sou ladr&egrave;s la',
'aucune_breve' => 'Gen pa oken tinouv&egrave;l sou ladr&egrave;s la',
'aucune_rubrique' => 'Gen pa oken ribrik sou ladr&egrave;s la',
'auteur' => 'Auteur', # NEW
'autres' => '<NEW>Ot',
'autres_breves' => 'L&ograve;t tinouv&egrave;l yo',
'autres_groupes_mots_clefs' => 'L&ograve;t gwoup mokle yo',
'autres_sites' => 'L&ograve;t sit yo',

// B
'bonjour' => 'Bonjou',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Tinouv&egrave;l yo',

// C
'commenter_site' => 'L&egrave;s yon komant&egrave; sou sit la',
'copie_document_impossible' => '<NEW>Pa ka kopye dokiman la',

// D
'date' => 'Dat',
'dernier_ajout' => 'D&egrave;nye bagay ki ajoute',
'dernieres_breves' => 'D&egrave;nye tinouv&egrave;l yo',
'derniers_articles' => 'D&egrave;nye atik yo',
'derniers_commentaires' => 'D&egrave;nye komant&egrave; yo',
'derniers_messages_forum' => 'D&egrave;nye mesaj yo ki te piblye nan fowom yo',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Ledisyon modt&egrave;ks pou',
'en_reponse' => 'Pou r&eacute;ponn a&nbsp;:',
'en_resume' => 'Nan k&egrave;k mo',
'envoyer_message' => 'Voye yon mesaj',
'espace_prive' => 'Espas priv&eacute;',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Fowom',

// H
'hierarchie_site' => 'Estrikti sit sa-a',

// J
'jours' => 'jou yo',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'M&egrave;m lot&egrave; ki ekri ank&ograve;',
'meme_rubrique' => 'Andan m&egrave;m ribrik',
'memes_auteurs' => 'M&egrave;m lot&egrave; yo ki ekri ank&ograve;',
'message' => 'Mesaj',
'messages_forum' => 'Mesaj yo nan fowom ',
'messages_recents' => 'Mesaj yo nan fowom ki plis resan',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Mokle yo',
'mots_clefs_meme_groupe' => 'Mokle yo nan m&egrave;m gwoup',

// N
'navigation' => 'Toune-vire',
'nom' => 'Kouman rele',
'nouveautes' => 'Nouv&egrave;lt&eacute; yo',
'nouveautes_web' => 'Kisa nouvo sou w&egrave;b la',
'nouveaux_articles' => 'Nouvo atik yo',
'nouvelles_breves' => 'Nouvo tinouv&egrave;l yo',

// P
'page_precedente' => 'paj d&egrave;y&egrave;',
'page_suivante' => 'paj swivan',
'par_auteur' => 'pa',
'participer_site' => 'Ou se kapab soutni vi sit la ek pwopoze ou pwop atik aw. Pou soutni kon sa enskri a w isit anba. Ou ke gen touswit ou kod laks&egrave; nan espas priv&eacute; sit la.',
'plan_site' => 'Kat sit la',
'popularite' => 'Kouman se popil&egrave;',
'poster_message' => 'Voye yon mesaj',
'proposer_site' => 'Ou se kapab pwopoze yon sit pou ajoute nan ribrik la&nbsp;:',

// R
'repondre_article' => 'Reponn sou atik la',
'repondre_breve' => 'Reponn sou tinouv&egrave;l la',
'repondre_message' => 'Reponn sou mesaj la',
'resultats_recherche' => 'Rezilta pou ou ch&egrave;che',
'retour_debut_forums' => 'Tounyen nan koumansman fowom sa-yo',
'rubrique' => 'Ribrik',
'rubriques' => 'Ribrik yo',

// S
'signatures_petition' => 'Siyati yo',
'site_realise_avec_spip' => 'Sit la  se sit ki te f&egrave; ak SPIP',
'sites_web' => 'Sitw&egrave;b yo',
'sous_rubriques' => 'Souribrik yo',
'spam' => 'Spam', # NEW
'suite' => 'swit',
'sur_web' => 'Sou w&egrave;b',
'syndiquer_rubrique' => 'Sindike ribrik la',
'syndiquer_site' => 'Sindike tout sit la m&egrave;m',

// T
'texte_lettre_information' => 'Tala l&egrave;t-enf&ograve;masyon sit la ',
'texte_lettre_information_2' => 'L&egrave;t la ka ramase tout atik ek tinouv&egrave;l yo  te pibliye depi',

// V
'ver_imprimer' => 'V&egrave;syon pou enprime',
'voir_en_ligne' => 'Gad an liy',
'voir_squelette' => 'kou je sou l&eacute;skel&egrave;t paj-la'
);

?>
